@@ -40,6 +40,16 @@ func NewPreflight(df cmdcore.DepsFactory, enabled bool) *Preflight {
 				&ChangeValidator{
 					Validations: []ChangeValidation{
 						EnumChangeValidation,
+						RequiredFieldChangeValidation,
+						MinimumChangeValidation,
+						MinimumItemsChangeValidation,
+						MinimumLengthChangeValidation,
+						MinimumPropertiesChangeValidation,
+						MaximumChangeValidation,
+						MaximumLengthChangeValidation,
+						MaximumItemsChangeValidation,
+						MaximumPropertiesChangeValidation,
+						DefaultValueChangeValidation,
 					},
 				},
 			},
