@@ -9,8 +9,8 @@ import (
 	"strconv"
 	"strings"
 
-	ctlconf "github.com/vmware-tanzu/carvel-kapp/pkg/kapp/config"
-	ctlres "github.com/vmware-tanzu/carvel-kapp/pkg/kapp/resources"
+	ctlconf "carvel.dev/kapp/pkg/kapp/config"
+	ctlres "carvel.dev/kapp/pkg/kapp/resources"
 	corev1 "k8s.io/api/core/v1"
 )
 
